@@ -3,7 +3,7 @@ All kinds of useful tools to use in pipelines.
 """
 from functools import partial, wraps
 from collections import deque
-from typing import Any
+from typing import Any, Mapping
 from dataclasses import dataclass
 from operator import not_
 
@@ -638,6 +638,8 @@ def iterize(func, name=None):
     Some call this "vectorization", but it's not really a vector, but an
     iterable, thus the name.
 
+    `iterize` is a partial of `map`.
+
     >>> f = lambda x: x * 10
     >>> f(2)
     20
@@ -715,6 +717,66 @@ def iterize(func, name=None):
     return wrapper(partial(map, func))
 
 
+def valmap(d: Mapping, func: Callable, copy_dict: bool = True):
+    """Apply func to the values of a shallow copy of d, unless copy_dict=False,
+    in which case, it will be applied to the input dict itself.
+
+    >>> d = {'a': 2, 'b': 3}
+    >>> valmap(d, lambda x: x * 10)
+    {'a': 20, 'b': 30}
+    >>> d  # see that d unchanged
+    {'a': 2, 'b': 3}
+    >>> valmap(d, lambda x: x * 10, copy_dict=False)  # but if we ask for it
+    {'a': 20, 'b': 30}
+    >>> # we still get a (transformed) dict in the output, but it's the same dict changed
+    >>> d  # now d itself changed
+    {'a': 20, 'b': 30}
+
+    """
+    if copy_dict:
+        return {k: func(v) for k, v in d.items()}
+    else:
+        for k in d:
+            d[k] = func(
+                d[k]
+            )  # pylint: disable (mapping needs to also be mutable here!)
+        return d
+
+
+def dictify(func, copy_dict=True, name=None):
+    """Makes a version of the input func that should be called on dictionaries and will
+    return dictionaries. The function will be applied to the values of a shallow
+    copy of the dict, unless copy_dict=False, in which case,
+    it will be applied to the input dict itself.
+
+    `dictify` is a partial of `valmap`
+
+    >>> mult_by_10 = lambda x: x * 10
+    >>> f = dictify(mult_by_10)
+    >>> d = {'a': 2, 'b': 3}
+    >>> f(d)
+    {'a': 20, 'b': 30}
+    >>> d  # see that d unchanged
+    {'a': 2, 'b': 3}
+    >>> f = dictify(mult_by_10, copy_dict=False)  # but if we ask for it
+    >>> f(d)
+    {'a': 20, 'b': 30}
+    >>> # we still get a (transformed) dict in the output, but it's the same dict changed
+    >>> d  # now d itself changed
+    {'a': 20, 'b': 30}
+
+    """
+    wrapper = mywraps(
+        func,
+        name=name,
+        doc_prefix=f"version of {func_name(func)} that should be called on dictionaries"
+        f"and will return dictionaries. The function will be applied to "
+        f"the values of a shallow copy of the dict, unless copy_dict=False, "
+        f" in which case, it will be applied to the input dict itself:\n",
+    )
+    return wrapper(partial(valmap, func=func, copy_dict=copy_dict))
+
+
 def wrap_first_arg_in_list(func):
     """Takes a func(X,...) function and returns a func([X],...) function."""
 
